<?php

namespace Annie\Evnt\Policies;

use Litepie\User\Contracts\UserPolicy;
use Annie\Evnt\Models\EventCollege;

class EventCollegePolicy
{

    /**
     * Determine if the given user can view the event_college.
     *
     * @param UserPolicy $user
     * @param EventCollege $event_college
     *
     * @return bool
     */
    public function view(UserPolicy $user, EventCollege $event_college)
    {
        if ($user->canDo('evnt.event_college.view') && $user->isAdmin()) {
            return true;
        }

        return $event_college->user_id == user_id() && $event_college->user_type == user_type();
    }

    /**
     * Determine if the given user can create a event_college.
     *
     * @param UserPolicy $user
     * @param EventCollege $event_college
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('evnt.event_college.create');
    }

    /**
     * Determine if the given user can update the given event_college.
     *
     * @param UserPolicy $user
     * @param EventCollege $event_college
     *
     * @return bool
     */
    public function update(UserPolicy $user, EventCollege $event_college)
    {
        if ($user->canDo('evnt.event_college.edit') && $user->isAdmin()) {
            return true;
        }

        return $event_college->user_id == user_id() && $event_college->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given event_college.
     *
     * @param UserPolicy $user
     * @param EventCollege $event_college
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, EventCollege $event_college)
    {
        return $event_college->user_id == user_id() && $event_college->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given event_college.
     *
     * @param UserPolicy $user
     * @param EventCollege $event_college
     *
     * @return bool
     */
    public function verify(UserPolicy $user, EventCollege $event_college)
    {
        if ($user->canDo('evnt.event_college.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given event_college.
     *
     * @param UserPolicy $user
     * @param EventCollege $event_college
     *
     * @return bool
     */
    public function approve(UserPolicy $user, EventCollege $event_college)
    {
        if ($user->canDo('evnt.event_college.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
