<?php

namespace Annie\Evnt\Policies;

use Litepie\User\Contracts\UserPolicy;
use Annie\Evnt\Models\EventComment;

class EventCommentPolicy
{

    /**
     * Determine if the given user can view the event_comment.
     *
     * @param UserPolicy $user
     * @param EventComment $event_comment
     *
     * @return bool
     */
    public function view(UserPolicy $user, EventComment $event_comment)
    {
        if ($user->canDo('evnt.event_comment.view') && $user->isAdmin()) {
            return true;
        }

        return $event_comment->user_id == user_id() && $event_comment->user_type == user_type();
    }

    /**
     * Determine if the given user can create a event_comment.
     *
     * @param UserPolicy $user
     * @param EventComment $event_comment
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('evnt.event_comment.create');
    }

    /**
     * Determine if the given user can update the given event_comment.
     *
     * @param UserPolicy $user
     * @param EventComment $event_comment
     *
     * @return bool
     */
    public function update(UserPolicy $user, EventComment $event_comment)
    {
        if ($user->canDo('evnt.event_comment.edit') && $user->isAdmin()) {
            return true;
        }

        return $event_comment->user_id == user_id() && $event_comment->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given event_comment.
     *
     * @param UserPolicy $user
     * @param EventComment $event_comment
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, EventComment $event_comment)
    {
        return $event_comment->user_id == user_id() && $event_comment->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given event_comment.
     *
     * @param UserPolicy $user
     * @param EventComment $event_comment
     *
     * @return bool
     */
    public function verify(UserPolicy $user, EventComment $event_comment)
    {
        if ($user->canDo('evnt.event_comment.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given event_comment.
     *
     * @param UserPolicy $user
     * @param EventComment $event_comment
     *
     * @return bool
     */
    public function approve(UserPolicy $user, EventComment $event_comment)
    {
        if ($user->canDo('evnt.event_comment.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
