<?php

namespace Annie\Evnt\Policies;

use Litepie\User\Contracts\UserPolicy;
use Annie\Evnt\Models\EventLike;

class EventLikePolicy
{

    /**
     * Determine if the given user can view the event_like.
     *
     * @param UserPolicy $user
     * @param EventLike $event_like
     *
     * @return bool
     */
    public function view(UserPolicy $user, EventLike $event_like)
    {
        if ($user->canDo('evnt.event_like.view') && $user->isAdmin()) {
            return true;
        }

        return $event_like->user_id == user_id() && $event_like->user_type == user_type();
    }

    /**
     * Determine if the given user can create a event_like.
     *
     * @param UserPolicy $user
     * @param EventLike $event_like
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('evnt.event_like.create');
    }

    /**
     * Determine if the given user can update the given event_like.
     *
     * @param UserPolicy $user
     * @param EventLike $event_like
     *
     * @return bool
     */
    public function update(UserPolicy $user, EventLike $event_like)
    {
        if ($user->canDo('evnt.event_like.edit') && $user->isAdmin()) {
            return true;
        }

        return $event_like->user_id == user_id() && $event_like->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given event_like.
     *
     * @param UserPolicy $user
     * @param EventLike $event_like
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, EventLike $event_like)
    {
        return $event_like->user_id == user_id() && $event_like->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given event_like.
     *
     * @param UserPolicy $user
     * @param EventLike $event_like
     *
     * @return bool
     */
    public function verify(UserPolicy $user, EventLike $event_like)
    {
        if ($user->canDo('evnt.event_like.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given event_like.
     *
     * @param UserPolicy $user
     * @param EventLike $event_like
     *
     * @return bool
     */
    public function approve(UserPolicy $user, EventLike $event_like)
    {
        if ($user->canDo('evnt.event_like.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
