<?php

namespace Annie\Evnt\Policies;

use Litepie\User\Contracts\UserPolicy;
use Annie\Evnt\Models\EventManager;

class EventManagerPolicy
{

    /**
     * Determine if the given user can view the event_manager.
     *
     * @param UserPolicy $user
     * @param EventManager $event_manager
     *
     * @return bool
     */
    public function view(UserPolicy $user, EventManager $event_manager)
    {
        if ($user->canDo('evnt.event_manager.view') && $user->isAdmin()) {
            return true;
        }

        return $event_manager->user_id == user_id() && $event_manager->user_type == user_type();
    }

    /**
     * Determine if the given user can create a event_manager.
     *
     * @param UserPolicy $user
     * @param EventManager $event_manager
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('evnt.event_manager.create');
    }

    /**
     * Determine if the given user can update the given event_manager.
     *
     * @param UserPolicy $user
     * @param EventManager $event_manager
     *
     * @return bool
     */
    public function update(UserPolicy $user, EventManager $event_manager)
    {
        if ($user->canDo('evnt.event_manager.edit') && $user->isAdmin()) {
            return true;
        }

        return $event_manager->user_id == user_id() && $event_manager->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given event_manager.
     *
     * @param UserPolicy $user
     * @param EventManager $event_manager
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, EventManager $event_manager)
    {
        return $event_manager->user_id == user_id() && $event_manager->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given event_manager.
     *
     * @param UserPolicy $user
     * @param EventManager $event_manager
     *
     * @return bool
     */
    public function verify(UserPolicy $user, EventManager $event_manager)
    {
        if ($user->canDo('evnt.event_manager.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given event_manager.
     *
     * @param UserPolicy $user
     * @param EventManager $event_manager
     *
     * @return bool
     */
    public function approve(UserPolicy $user, EventManager $event_manager)
    {
        if ($user->canDo('evnt.event_manager.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
