<?php

namespace Annie\Evnt\Policies;

use Litepie\User\Contracts\UserPolicy;
use Annie\Evnt\Models\EventProject;

class EventProjectPolicy
{

    /**
     * Determine if the given user can view the event_project.
     *
     * @param UserPolicy $user
     * @param EventProject $event_project
     *
     * @return bool
     */
    public function view(UserPolicy $user, EventProject $event_project)
    {
        if ($user->canDo('evnt.event_project.view') && $user->isAdmin()) {
            return true;
        }

        return $event_project->user_id == user_id() && $event_project->user_type == user_type();
    }

    /**
     * Determine if the given user can create a event_project.
     *
     * @param UserPolicy $user
     * @param EventProject $event_project
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('evnt.event_project.create');
    }

    /**
     * Determine if the given user can update the given event_project.
     *
     * @param UserPolicy $user
     * @param EventProject $event_project
     *
     * @return bool
     */
    public function update(UserPolicy $user, EventProject $event_project)
    {
        if ($user->canDo('evnt.event_project.edit') && $user->isAdmin()) {
            return true;
        }

        return $event_project->user_id == user_id() && $event_project->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given event_project.
     *
     * @param UserPolicy $user
     * @param EventProject $event_project
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, EventProject $event_project)
    {
        return $event_project->user_id == user_id() && $event_project->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given event_project.
     *
     * @param UserPolicy $user
     * @param EventProject $event_project
     *
     * @return bool
     */
    public function verify(UserPolicy $user, EventProject $event_project)
    {
        if ($user->canDo('evnt.event_project.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given event_project.
     *
     * @param UserPolicy $user
     * @param EventProject $event_project
     *
     * @return bool
     */
    public function approve(UserPolicy $user, EventProject $event_project)
    {
        if ($user->canDo('evnt.event_project.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
